passletters
===========

Read password from stdin and echo it with letters enumerated (for entry into web prompts). Clear terminal afterwards.

Installation:
```
sudo pip install passletters
```
**NB**: sudo may be needed to install the `passletters` script somewhere in your PATH.

PyPI: https://pypi.python.org/pypi/passletters
